Struct style::invalidation::element::invalidator::Invalidation
[−]
[src]
pub struct Invalidation<'a> { /* fields omitted */ }An Invalidation is a complex selector that describes which elements,
relative to a current element we are processing, must be restyled.
Methods
impl<'a> Invalidation<'a>[src]
pub fn new(selector: &'a Selector<SelectorImpl>, offset: usize) -> Self[src]
Create a new invalidation for a given selector and offset.